[Libreoffice-commits] core.git: svx/source

Julien Nabet serval2412 at yahoo.fr
Sun Jan 18 12:36:32 PST 2015


 svx/source/fmcomp/fmgridcl.cxx |   18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

New commits:
commit f9bea19eeab49cb9e6fcdd3ae5e777da9dc882ca
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Sun Jan 18 21:35:09 2015 +0100

    Typo: sDatasouce->sDatasource
    
    Change-Id: I4ffaf4195ae17ecf86dffc9c44e4672c4b2835d7

diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index a611b54..4418a47 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -237,7 +237,7 @@ sal_Int8 FmGridHeader::ExecuteDrop( const ExecuteDropEvent& _rEvt )
     }
 
     // extract the descriptor
-    OUString sDatasouce, sCommand, sFieldName,sDatabaseLocation,sConnnectionResource;
+    OUString sDatasource, sCommand, sFieldName,sDatabaseLocation,sConnnectionResource;
     sal_Int32       nCommandType = CommandType::COMMAND;
     Reference< XPreparedStatement >     xStatement;
     Reference< XResultSet >             xResultSet;
@@ -245,7 +245,7 @@ sal_Int8 FmGridHeader::ExecuteDrop( const ExecuteDropEvent& _rEvt )
     Reference< XConnection >            xConnection;
 
     ODataAccessDescriptor aColumn = OColumnTransferable::extractColumnDescriptor(aDroppedData);
-    if (aColumn.has(daDataSource))  aColumn[daDataSource]   >>= sDatasouce;
+    if (aColumn.has(daDataSource))  aColumn[daDataSource]   >>= sDatasource;
     if (aColumn.has(daDatabaseLocation))    aColumn[daDatabaseLocation] >>= sDatabaseLocation;
     if (aColumn.has(daConnectionResource))  aColumn[daConnectionResource] >>= sConnnectionResource;
     if (aColumn.has(daCommand))     aColumn[daCommand]      >>= sCommand;
@@ -256,7 +256,7 @@ sal_Int8 FmGridHeader::ExecuteDrop( const ExecuteDropEvent& _rEvt )
 
     if  (   sFieldName.isEmpty()
         ||  sCommand.isEmpty()
-        ||  (   sDatasouce.isEmpty()
+        ||  (   sDatasource.isEmpty()
             &&  sDatabaseLocation.isEmpty()
             &&  !xConnection.is()
             )
@@ -273,12 +273,12 @@ sal_Int8 FmGridHeader::ExecuteDrop( const ExecuteDropEvent& _rEvt )
         {   // the transferable did not contain the connection -> build an own one
             try
             {
-                OUString sSignificantSource( sDatasouce.isEmpty() ? sDatabaseLocation : sDatasouce );
+                OUString sSignificantSource( sDatasource.isEmpty() ? sDatabaseLocation : sDatasource );
                 xConnection = OStaticDataAccessTools().getConnection_withFeedback(sSignificantSource, OUString(), OUString(),
                                   static_cast<FmGridControl*>(GetParent())->getContext() );
             }
             catch(NoSuchElementException&)
-            {   // allowed, means sDatasouce isn't a valid data source name ....
+            {   // allowed, means sDatasource isn't a valid data source name ....
             }
             catch(Exception&)
             {
@@ -374,8 +374,8 @@ IMPL_LINK( FmGridHeader, OnAsyncExecuteDrop, void*, /*NOTINTERESTEDIN*/ )
     Reference< XPropertySet >   xField;
     Reference< XConnection >    xConnection;
 
-    OUString sDatasouce = m_pImpl->aDropData.getDataSource();
-    if ( sDatasouce.isEmpty() && m_pImpl->aDropData.has(daConnectionResource) )
+    OUString sDatasource = m_pImpl->aDropData.getDataSource();
+    if ( sDatasource.isEmpty() && m_pImpl->aDropData.has(daConnectionResource) )
         m_pImpl->aDropData[daConnectionResource]    >>= sURL;
     m_pImpl->aDropData[daCommand]       >>= sCommand;
     m_pImpl->aDropData[daCommandType]   >>= nCommandType;
@@ -585,8 +585,8 @@ IMPL_LINK( FmGridHeader, OnAsyncExecuteDrop, void*, /*NOTINTERESTEDIN*/ )
         {
             if (::comphelper::getString(xForm->getPropertyValue(FM_PROP_DATASOURCE)).isEmpty())
             {
-                if ( !sDatasouce.isEmpty() )
-                    xForm->setPropertyValue(FM_PROP_DATASOURCE, makeAny(sDatasouce));
+                if ( !sDatasource.isEmpty() )
+                    xForm->setPropertyValue(FM_PROP_DATASOURCE, makeAny(sDatasource));
                 else
                     xForm->setPropertyValue(FM_PROP_URL, makeAny(sURL));
             }


More information about the Libreoffice-commits mailing list